OC.L10N.register(
    "core",
    {
    "Please select a file." : "Пожалуйста выберите файл.",
    "File is too big" : "Файл слишком велик",
    "Invalid file provided" : "Указан неправильный файл",
    "No image or file provided" : "Не указано изображение или файл",
    "Unknown filetype" : "Неизвестный тип файла",
    "Invalid image" : "Некорректное изображение",
    "An error occurred. Please contact your admin." : "Произошла ошибка. Пожалуйста, свяжитесь с Вашим администратором.",
    "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
    "No crop data provided" : "Не указана информация о кадрировании",
    "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
    "Crop is not square" : "Кадр не является квадратом",
    "Could not reset password because the token is invalid" : "Не удалось сбросить пароль, так как токен неправильный",
    "Could not reset password because the token expired" : "Не удалось сбросить пароль, так как токен устарел",
    "Could not reset password because the token does not match" : "Не удалось сбросить пароль, так как токен не соответствует",
    "%s password changed successfully" : "Пароль %s изменён успешно",
    "%s password reset" : "Сброс пароля %s",
    "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Пожалуйста, свяжитесь с вашим администратором.",
    "Download / View" : "Скачивание / Просмотр",
    "Recipients can view or download contents." : "Получатели могут просматривать или скачивать содержимое.",
    "Download / View / Upload" : "Скачивание / Просмотр / Закачка",
    "Recipients can view, download and upload contents." : "Получатели могут просматривать, скачивать и закачивать содержимое.",
    "Download / View / Edit" : "Скачивание / Просмотр / Правка",
    "Recipients can view, download, edit, delete and upload contents." : "Получатели могут просматривать, скачивать, править, удалять и закачивать содержимое.",
    "Upload only" : "Только закачка",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Получение файлов от многих получателей без раскрытия содержимого каталога.",
    "Preparing update" : "Подготовка к обновлению",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Предупреждение восстановления:",
    "Repair error: " : "Ошибка восстановления:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Пожалуйста, используйте обновление через командную строку, так как автоматические обновления отключены в config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
    "Turned on maintenance mode" : "Режим отладки включён",
    "Turned off maintenance mode" : "Режим отладки отключён",
    "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
    "Updating database schema" : "Обновление схемы базы данных",
    "Updated database" : "База данных обновлена",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных (это может занять длительное время в зависимости от размера базы данных)",
    "Checked database schema update" : "Проверено обновление схемы БД",
    "Checking updates of apps" : "Проверка обновлений для приложений",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных для %s (это может занять длительное время в зависимости от размера базы данных)",
    "Checked database schema update for apps" : "Проверено обновление схемы БД приложений",
    "Updated \"%s\" to %s" : "Обновлено \"%s\" до %s",
    "Set log level to debug" : "Установить журнал в режим отладки",
    "Reset log level" : "Сбросить уровень журнала",
    "Starting code integrity check" : "Начинается проверка целостности кода",
    "Finished code integrity check" : "Проверка целостности кода завершина",
    "%s (3rdparty)" : "%s (стороннее)",
    "%s (incompatible)" : "%s (несовместим)",
    "Following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
    "Already up to date" : "Не нуждается в обновлении",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Sun." : "Вс.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Вс",
    "Mo" : "Пн",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Чт",
    "Fr" : "Пт",
    "Sa" : "Сб",
    "January" : "Январь",
    "February" : "Февраль",
    "March" : "Март",
    "April" : "Апрель",
    "May" : "Май",
    "June" : "Июнь",
    "July" : "Июль",
    "August" : "Август",
    "September" : "Сентябрь",
    "October" : "Октябрь",
    "November" : "Ноябрь",
    "December" : "Декабрь",
    "Jan." : "Янв.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Май.",
    "Jun." : "Июн.",
    "Jul." : "Июл.",
    "Aug." : "Авг.",
    "Sep." : "Сен.",
    "Oct." : "Окт.",
    "Nov." : "Ноя.",
    "Dec." : "Дек.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\"> Были обнаружены проблемы с проверкой целостности кода. Подробнее ...",
    "Settings" : "Настройки",
    "Problem loading page, reloading in 5 seconds" : "Возникла проблема при загрузке страницы, повторная попытка через 5 секунд",
    "Saving..." : "Сохранение...",
    "Dismiss" : "Закрыть",
    "seconds ago" : "несколько секунд назад",
    "You have enabled one or more ownCloud Enterprise apps but your installation does not have a valid license yet." : "Вы включили одно или несколько приложений ownCloud для Enterprise, но у вашей установки ещё нет допустимого лицензионного ключа.",
    "A grace period of 24 hours has started to allow you to get going right away. Once the grace period ends, all Enterprise apps will become disabled unless you supply a valid license key." : "Запущен дополнительный период на 24 часа, чтобы вы смогли продвинуться дальше. Как только дополнительный период закончится, все приложения для Enterprise будут отключны, если вы не введёте допустимый лицензионный ключ.",
    "To try ownCloud Enterprise, just start a 30-day demo and enter the provided license key below." : "Чтобы попробовать ownCloud Enterprise, просто запустите 30-дневную демонстрацию и введите ниже предоставленный лицензионный ключ.",
    "Upgrade to ownCloud Enterprise" : "Обновление ownCloud до Enterprise",
    "Remaining time: {rtime}" : "Остающееся время: {rtime}",
    "Get your demo key" : "Получить демонстрационный ключ",
    "Enter license key" : "Ввод лицензионного ключа",
    "Set new key" : "Установить новый ключ",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ссылка для сброса пароля была отправлена на ваш email. Если вы не получили письмо в течении разумного промежутка времени, проверьте папку со спамом.<br>Если его там нет, то обратитесь к вашему администратору.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваши файлы зашифрованы. Если вы не включили ключ восстановления, то ваши данные будут недоступны после сброса пароля.<br />Если вы не уверены что делать дальше - обратитесь к вашему администратору.<br />Вы действительно хотите продолжить?",
    "I know what I'm doing" : "Я понимаю, что делаю",
    "Password can not be changed. Please contact your administrator." : "Пароль не может быть изменён. Пожалуйста, свяжитесь с вашим администратором.",
    "Passwords do not match" : "Пароли не соответствуют друг другу",
    "Error adding {addItem}: {addItem} already exists" : "Ошибка при добавлении {addItem}: {addItem} уже существует",
    "No" : "Нет",
    "Yes" : "Да",
    "Choose" : "Выбрать",
    "Error loading file picker template: {error}" : "Ошибка при загрузке шаблона выбора файлов: {error}",
    "Ok" : "Ок",
    "Error loading message template: {error}" : "Ошибка загрузки шаблона сообщений: {error}",
    "read-only" : "только для чтения",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} конфликт в файлах","{count} конфликта в файлах","{count} конфликтов в файлах","{count} конфликтов в файлах"],
    "One file conflict" : "Один конфликт в файлах",
    "New Files" : "Новые файлы",
    "Already existing files" : "Существующие файлы",
    "Which files do you want to keep?" : "Какие файлы вы хотите сохранить?",
    "If you select both versions, the copied file will have a number added to its name." : "При выборе обеих версий, к названию копируемого файла будет добавлена цифра",
    "Cancel" : "Отмена",
    "Continue" : "Продолжить",
    "(all selected)" : "(все выбранные)",
    "({count} selected)" : "(выбрано: {count})",
    "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
    "Very weak password" : "Очень слабый пароль",
    "Weak password" : "Слабый пароль",
    "So-so password" : "Так себе пароль",
    "Good password" : "Хороший пароль",
    "Strong password" : "Устойчивый к взлому пароль",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер еще не настроен должным образом чтобы позволить синхронизацию файлов, потому что интерфейс WebDAV, кажется, испорчен.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Ваш веб-сервер настроен не корректно для разрешения \"{url}\". Дополнительная информация может быть найдена в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Этот сервер не имеет подключения к Интернету. Это означает, что некоторые из функций, таких как внешнее хранилище, уведомления об обновлениях и установка сторонних приложений не будут работать. Доступ к файлам удаленно и отправки уведомлений по почте могут не работать. Рекомендуется разрешить данному серверу доступ в Интернет если хотите, чтобы все функции работали.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Не настроена система кеширования. Для увеличения производительности сервера, по возможности, настройте memcache. Более подробная информация в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP не имеет доступа на чтение к /dev/urandom, что крайне нежелательно по соображениям безопасности. Дополнительную информацию можно найти в нашей <a target=\"_blank\" href=\"{docLink}\"> документации </a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Вы используете PHP {version}. Рекомендуется обновить версию PHP, чтобы воспользоваться <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">улучшениями производительности и безопасности, внедрёнными PHP Group</a> как только новая версия будет доступна в Вашем дистрибутиве. ",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Конфигурация заголовков обратного прокси не верна, либо доступ к ownCloud осуществлён через доверенный прокси. Если ownCloud открыт не через доверенный прокси то это проблема безопасности, которая может позволить атакующему подделать IP адрес, который видит ownCloud. Дополнительная информация доступна в нашей  <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached настроен на распределенный кеш, но установлен не поддерживаемый модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только модуль \"memcached\", но не \"memcache\". Больше информации на <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">wiki странице memcached о обоих модулях</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему доступна в нашей <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">документации</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Список проблемных файлов…</a> / <a href=\"{rescanEndpoint}\">Сканировать ещё раз…</a>)",
    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Вы работаете в ОТЛАДОЧНОМ режиме, и это может давать нежелательные побочные эффекты. Пожалуйста уберите флаг «debug» из «config.php».",
    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог данных и ваши файлы возможно доступны из Интернета. Файл .htaccess не работает. Мы настоятельно рекомендуем Вам настроить веб сервер таким образом, чтобы каталог данных не был больше доступен или переместить каталог данных за пределы корня веб сервера.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Заголовок HTTP \"{header}\" не настроен на значение \"{expected}\". Это потенциальная проблема безопасности и мы рекомендуем изменить эти настройки.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Заголовок HTTP \"Strict-Transport-Security\" должен быть настроен как минимум на \"{seconds}\" секунд. Для улучшения безопасности рекомендуется включить HSTS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Вы зашли на этот сайт через HTTP. Мы настоятельно рекомендуем настроить ваш сервер на использование HTTPS согласно нашим <a href=\"{docUrl}\">подсказкам по безопасности</a>.",
    "Shared" : "Общий доступ",
    "Shared with {recipients}" : "Вы поделились с {recipients}",
    "Error" : "Ошибка",
    "Error while sharing" : "При попытке поделиться произошла ошибка",
    "Error while unsharing" : "При закрытии доступа произошла ошибка",
    "The public link will expire no later than {days} days after it is created" : "Срок действия публичной ссылки истекает не позже чем через {days} дней после её создания",
    "Expiration" : "Срок действия",
    "Choose an expiration date" : "Выберите срок действия",
    "Expiration date is required" : "Срок действия обязателен",
    "Delete {link}" : "Удалить {link}",
    "Remove link" : "Удалить ссылку",
    "Link" : "Ссылка",
    "Create public link" : "Создать общедоступную ссылку",
    "Edit" : "Редактировать",
    "Remove" : "Удалить",
    "Copy to clipboard" : "Скопировать в буфер обмена",
    "Social share" : "Поделиться в соцсетях",
    "There are currently no link shares, you can create one" : "Сейчас нет ссылок для доступа, вы можете создать первую",
    "Anyone with the link has access to the file/folder" : "Каждый, у кого есть эта ссылка, имеет доступ к файлу/каталогу",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C чтобы скопировать.",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C чтобы скопировать.",
    "Choose a password" : "Выберите пароль",
    "Password required" : "Требуется пароль",
    "Link name" : "Имя ссылки",
    "Name" : "Название",
    "Filename" : "Имя файла",
    "Password" : "Пароль",
    "Can not remove required password" : "Нельзя удалить обязательный пароль",
    "Edit link share: {name}" : "Изменить доступ по ссылке: {name}",
    "Create link share: {name}" : "Создать доступ по ссылке: {name}",
    "Share" : "Поделиться",
    "Save" : "Сохранить",
    "Remove password" : "Удалить пароль",
    "Share to Twitter. Opens in a new window." : "Поделиться в Twitter. Откроется в новом окне",
    "Share to Facebook. Opens in a new window." : "Поделиться в Facebook. Откроется в новом окне",
    "Share to Diaspora. Opens in a new window." : "Поделиться в Diaspora. Откроется в новом окне",
    "Share to Google+. Opens in a new window." : "Поделиться в Google+. Откроется в новом окне",
    "Share via email. Opens your mail client." : "Поделиться через  email. Откроется в вашем почтовом клиенте",
    "An error occurred while sending email" : "При отправке письма произошла ошибка.",
    "Email link to person" : "Отправить ссылку по электронной почте",
    "Send copy to self" : "Отправить копию себе",
    "Send link via email" : "Отправить ссылку по электронной почте",
    "Add personal message" : "Добавить личное сообщение",
    "Sending" : "Отправка",
    "E-Mail sent" : "Письмо отправлено",
    "Shared with you and the group {group} by {owner}" : "{owner} поделился с вами и группой {group} ",
    "Shared with you by {owner}" : "С вами поделился {owner} ",
    "group" : "группа",
    "federated" : "федеративный",
    "notify by email" : "уведомить по почте",
    "Unshare" : "Закрыть доступ",
    "can share" : "может делиться с другими",
    "can edit" : "может редактировать",
    "create" : "создать",
    "change" : "изменить",
    "delete" : "удалить",
    "access control" : "контроль доступа",
    "Could not unshare" : "Не удалось отменить доступ",
    "Email notification was sent!" : "Уведомление почтой было отправлено!",
    "Email notification not sent" : "Уведомление почтой не было отправлено",
    "Share details could not be loaded for this item." : "Не удалось загрузить информацию об общем доступе для этого элемента.",
    "No users or groups found for {search}" : "Не найдено пользователей или групп по запросу {search}",
    "No users found for {search}" : "Не найдено пользователей по запросу {search}",
    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Пожалуйста введите хотя бы {chars} символ для вывода предложений","Пожалуйста введите хотя бы {chars} символа для вывода предложений","Пожалуйста введите хотя бы {chars} символов для вывода предложений","Пожалуйста введите хотя бы {chars} символов для вывода предложений"],
    "An error occurred. Please try again" : "Произошла ошибка. Попробуйте ещё раз",
    "User" : "Пользователь",
    "Group" : "Группа",
    "Guest" : "Гость",
    "At {server}" : "На {server}",
    "Federated" : "Федеративный",
    "User and Groups" : "Пользователь и группы",
    "Public Links" : "Общедоступные ссылки",
    "Sharing is not allowed" : "Предоставление доступа не разрешено",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поделиться с людьми на других серверах ownCloud используя формат username@example.com/owncloud",
    "Share with users…" : "Поделиться с пользователями...",
    "Share with users, groups or remote users…" : "Поделиться с пользователями, группами или удаленными пользователями...",
    "Share with users or groups…" : "Поделиться с пользователями или группами...",
    "Share with users or remote users…" : "Общий доступ с пользователями или удалеными пользователями",
    "Error removing share" : "Ошибка удаления общего доступа",
    "Unknown Share" : "Неизвестный ресурс общего доступа",
    "Non-existing tag #{tag}" : "Несуществующий тег #{tag}",
    "restricted" : "ограниченный",
    "invisible" : "невидимый",
    "Static" : "Статично",
    "({scope})" : "({scope})",
    "Delete" : "Удалить",
    "Rename" : "Переименовать",
    "Collaborative tags" : "Совместные теги",
    "The object type is not specified." : "Тип объекта не указан",
    "Enter new" : "Ввести новое",
    "Add" : "Добавить",
    "Edit tags" : "Изменить метки",
    "Error loading dialog template: {error}" : "Ошибка загрузки шаблона диалога: {error}",
    "No tags selected for deletion." : "Не выбраны метки для удаления.",
    "unknown text" : "неизвестный текст",
    "Hello world!" : "Привет мир!",
    "sunny" : "солнечно",
    "Hello {name}, the weather is {weather}" : "Здравствуйте {name}, погода {weather}",
    "Hello {name}" : "Здравствуйте {name}",
    "new" : "новый",
    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файлов"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Идет обновление. Покидая эту страницу, вы можете прервать процесс обновления.",
    "Updating to {version}" : "Обновляем до {version}",
    "An error occurred." : "Произошла ошибка.",
    "Please reload the page." : "Пожалуйста, обновите страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление прошло не успешно. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нащем форуме</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "При обновлении произошла ошибка. Пожалуйста сообщите об этом <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">сообществу ownCloud</a>.",
    "The update was successful. There were warnings." : "Обновление прошло успешно. Были предупреждения.",
    "The update was successful. Redirecting you to ownCloud now." : "Обновление прошло успешно. Перенаправляем в ownCloud.",
    "Searching other places" : "Идет поиск в других местах",
    "No search results in other folders" : "В других папках ничего не найдено",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат в другой папке","{count} результата в другой папке","{count} результатов в другой папке","{count} результатов в других папках"],
    "Personal" : "Личное",
    "Users" : "Пользователи",
    "Apps" : "Приложения",
    "Admin" : "Администрирование",
    "Help" : "Помощь",
    "Access forbidden" : "Доступ запрещён",
    "File not found" : "Файл не найден",
    "The specified document has not been found on the server." : "Указанный документ не найден на сервере.",
    "You can click here to return to %s." : "Вы можете нажать здесь, чтобы вернуться в %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Здравствуйте,\n\n%s поделился %s с вами.\nПосмотреть: %s\n",
    "The share will expire on %s." : "Доступ будет закрыт %s",
    "Personal note from the sender: \n %s." : "Личная заметка от отправителя: \n %s.",
    "Cheers!" : "Всего наилучшего!",
    "Internal Server Error" : "Внутренняя ошибка сервера",
    "The server encountered an internal error and was unable to complete your request." : "Запрос не выполнен, на сервере произошла ошибка.",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Если эта ошибка будет повторяться, то пожалуйста свяжитесь с администратором этого сервера, и приложите к сообщению технические подробности, приведённые ниже.",
    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Дополнительные подробности можно найти в <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">журнале сервера</a>.",
    "Technical details" : "Технические детали",
    "Remote Address: %s" : "Удаленный адрес: %s",
    "Request ID: %s" : "ID Запроса: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Сообщение: %s",
    "File: %s" : "Файл: %s",
    "Line: %s" : "Линия: %s",
    "Trace" : "Трассировка",
    "Imprint" : "Штамп",
    "Privacy Policy" : "Политика конфиденциальности",
    "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
    "Username" : "Имя пользователя",
    "Storage & database" : "Хранилище и база данных",
    "Data folder" : "Каталог с данными",
    "Configure the database" : "Настройка базы данных",
    "Only %s is available." : "Доступен только %s.",
    "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
    "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
    "Database user" : "Пользователь базы данных",
    "Database password" : "Пароль базы данных",
    "Database name" : "Название базы данных",
    "Database tablespace" : "Табличое пространство базы данных",
    "Database host" : "Хост базы данных",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Пожалуйста, вместе с именем хоста укажите и номер порта (например, localhost: 5432).",
    "Performance warning" : "Предупреждение о производительности",
    "SQLite will be used as database." : "В качестве базы данных будет использована SQLite.",
    "For larger installations we recommend to choose a different database backend." : "Для крупных проектов мы советуем выбрать другой тип базы данных.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "В частности не рекомендуется использовать SQLite при синхронизации файлов с использованием клиента для ПК.",
    "Finish setup" : "Завершить установку",
    "Finishing …" : "Завершение...",
    "Need help?" : "Нужна помощь?",
    "See the documentation" : "Посмотреть документацию",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Здравствуйте,<br><br>%s поделился с вами <strong>%s</strong>.<br>Перейдите по <a href=\"%s\">ссылке</a>, чтобы посмотреть<br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript. Пожалуйста, {linkstart}включите JavaScript{linkend} и обновите страницу.",
    "Menu" : "Меню",
    "Log out" : "Выйти",
    "Search" : "Найти",
    "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
    "Please contact your administrator." : "Пожалуйста, обратитесь к администратору.",
    "An internal error occurred." : "Произошла внутренняя ошибка.",
    "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
    "Login" : "Логин",
    "Username or email" : "Имя пользователя / email",
    "You took too long to log in, please try again now" : "Похоже, вы потратили на вход слишком много времени, пожалуйста попробуйте ещё раз сейчас",
    "Wrong password. Reset it?" : "Неправильный пароль. Сбросить его?",
    "Wrong password." : "Неправильный пароль.",
    "You are trying to access a private link. Please log in first." : "Вы пытаетесь получить доступ по личной ссылке. Пожалуйста, сначала войдите.",
    "Stay logged in" : "Оставаться в системе",
    "Alternative Logins" : "Альтернативные имена пользователя",
    "Use the following link to reset your password: {link}" : "Используйте следующую ссылку чтобы сбросить пароль: {link}",
    "Password changed successfully" : "Пароль изменён успешно",
    "New password" : "Новый пароль",
    "New Password" : "Новый пароль",
    "Confirm Password" : "Подтвердите пароль",
    "Reset password" : "Сбросить пароль",
    "Personal note from the sender: <br> %s." : "Личная заметка от отправителя: <br> %s.",
    "This ownCloud instance is currently in single user mode." : "Сервер ownCloud в настоящее время работает в однопользовательском режиме.",
    "This means only administrators can use the instance." : "Это значит, что только администраторы могут использовать сервер.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
    "Thank you for your patience." : "Спасибо за терпение.",
    "Two-step verification" : "Двухшаговая проверка",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Для вашей учётной записи включена повышенная безопасность. Пожалуйста, аутентифицируйтесь через второй фактор.",
    "Cancel login" : "Отменить вход",
    "Please authenticate using the selected factor." : "Пожалуйста, аутентифицируйтесь выбранным фактором.",
    "An error occurred while verifying the token" : "Произошла ошибка при проверке токена",
    "You are accessing the server from an untrusted domain." : "Вы пытаетесь получить доступ к серверу с недоверенного домена.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "Пожалуйста, обратитесь к вашему администратору. Если вы являетесь администратором этого экземпляра, то настройте параметр «trusted_domains» в config/config.php.",
    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Пример настройки имеется в config/config.sample.php или в <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документации</a>.",
    "App update required" : "Требуется обновление приложения",
    "%s will be updated to version %s" : "%s будет обновлен до версии %s",
    "These apps will be updated:" : "Следующие приложения будут обновлены:",
    "The theme %s has been disabled." : "Тема %s была отключена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
    "Start update" : "Запустить обновление",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
    "Detailed logs" : "Подбробные логи",
    "Update needed" : "Требуется обновление",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Возможно, что ваш экземпляр может содержать много файлов и/или пользователей. Чтобы обеспечить плавный процесс обновления, используйте обновление через командную строку(occ upgrade).",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Автоматическое обновление отключается в config.php. Для обновления вашего экземпляра, пожалуйста, используйте командную строку(occ upgrade).",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Для помощи, ознакомьтесь с  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документацией</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
    "This page will refresh itself when the %s instance is available again." : "Эта страница автоматически обновится, когда сервер %s снова станет доступен."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
